StringListFinder class

StringListFinder klassi berilgan so'zning indeksini ro'yxatdan topish uchun ishlatiladi.

Constructors

StringListFinder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

findIndexOfWord(List<String> list, String word) int
findIndexOfWord funksiyasi berilgan list ro'yxatidan word so'zining indeksini qaytaradi. Agar so'z topilmasa, -1 qiymati qaytariladi.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited