StringListFinder class

Constructors

StringListFinder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

findIndexOfWord(List<String> list, String word) int
Ushbu usul taqdim etilgan ro'yxatdagi so'zning indeksini qaytaradi. Agar so'z topilmasa, u -1 ni qaytaradi.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited